.. _top_{{objname}}:
.. role:: hidden
    :class: hidden-section
.. currentmodule:: {{ module }}


{{ name | underline}}

.. autoclass:: {{ objname }}

.. rubric:: Reference Details

.. ----

{% for item in members %}
{% if item in ['__call__'] %}
.. automethod:: {{ objname }}.{{ item }}
{% endif %}
{% endfor %}

.. :ref:`back to top <top_{{objname}}>`

.. ----

{% for item in methods %}
{% if item != '__init__' %}
.. automethod:: {{ objname }}.{{ item }}
{% endif %}
{% endfor %}

.. :ref:`back to top <top_{{objname}}>`

----

{% for item in attributes %}
.. autoattribute:: {{ objname }}.{{ item }}
{% endfor %}

:ref:`back to top <top_{{objname}}>`


.. autogenerated from _templates/autosummary/class.rst